@@ -10,7 +10,7 @@ require POSIX;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '1.09'; # keep same as in Tty.pm
+$VERSION = '1.11'; # keep same as in Tty.pm
 
 @ISA = qw(IO::Handle);
 eval { local $^W = 0; undef local $SIG{__DIE__}; require IO::Stty };
@@ -84,7 +84,7 @@ sub make_slave_controlling_terminal {
   my $self = shift;
   local(*DEVTTY);
 
-  # loose controlling terminal explicitely
+  # loose controlling terminal explicitly
   if (defined TIOCNOTTY) {
     if (open (\*DEVTTY, "/dev/tty")) {
       ioctl( \*DEVTTY, TIOCNOTTY, 0 );
@@ -124,6 +124,9 @@ sub make_slave_controlling_terminal {
       if (not defined ioctl( ${*$self}{'io_pty_slave'}, TCSETCTTY, 0 )) {
         warn "warning: TCSETCTTY failed, slave might not be set as controlling terminal: $!" if $^W;
       }
+    } else {
+      warn "warning: You have neither TIOCSCTTY nor TCSETCTTY on your system\n" if $^W;
+      return 0;
     }
   }
 
@@ -138,6 +141,8 @@ sub make_slave_controlling_terminal {
 }
 
 *clone_winsize_from = \&IO::Tty::clone_winsize_from;
+*get_winsize = \&IO::Tty::get_winsize;
+*set_winsize = \&IO::Tty::set_winsize;
 *set_raw = \&IO::Tty::set_raw;
 
 1;
@@ -150,7 +155,7 @@ IO::Pty - Pseudo TTY object class
 
 =head1 VERSION
 
-1.09
+1.11
 
 =head1 SYNOPSIS
 
@@ -251,6 +256,17 @@ silently returns OK.
 
 See the C<try> script for example code how to propagate SIGWINCH.
 
+=item get_winsize()
+
+Returns the terminal size, in a 4-element list.
+
+ ($row, $col, $xpixel, $ypixel) = $tty->get_winsize()
+
+=item set_winsize($row, $col, $xpixel, $ypixel)
+
+Sets the terminal size. If not specified, C<$xpixel> and C<$ypixel> are set to
+0.  As with C<clone_winsize_from>, this must be called upon the I<slave>.
+
 =back
 
 
